@@ -527,22 +527,25 @@ archigrow<-function(inputlie=NULL, inputtps=NULL, inputrsml=NULL,  res=NULL, uni
         if (is.null(twod)==TRUE){
         
         LIE[[i]]$col<-colors[as.matrix(LIE[[i]][,c("root", "Date")])]
-        
         root<-sum(LIE[[i]]$Suiv==0)
         end<-which(LIE[[i]]$Suiv==0)
-        open3d()
-        plot3d(x=LIE[[i]]$X[1], y=LIE[[i]]$Y[1], z=LIE[[i]]$Z[1], type="n", xlim=xlim1, ylim=ylim1, zlim=zlim1, main=main1, ylab=ylab1, xlab=xlab1, zlab=zlab1,...)
+        
+        if (!requireNamespace("rgl", quietly = TRUE)) {
+          stop("3D plotting with archigrow() requires package `rgl`. Please install it and try again.")}
+        
+        rgl::open3d()
+        rgl::plot3d(x=LIE[[i]]$X[1], y=LIE[[i]]$Y[1], z=LIE[[i]]$Z[1], type="n", xlim=xlim1, ylim=ylim1, zlim=zlim1, main=main1, ylab=ylab1, xlab=xlab1, zlab=zlab1,...)
         for (k in 1:root){
           if (k==1) {
             dataroot<-as.matrix(LIE[[i]][k:end[k],c(7:9, ncol(LIE[[i]]))])} 
           else {
             if (LIE[[i]]$Prec[end[k-1]+1]!=0){
               dataroot<-as.matrix(LIE[[i]][(end[k-1]+1):end[k],c(7:9, ncol(LIE[[i]]))])
-              dataroot<-as.matrix(rbind(LIE[[i]][LIE[[i]]$Num==LIE[[i]]$Prec[end[k-1]+1],c(7:9, ncol(LIE[[i]]))], dataroot))}
+              dataroot<-rbind(LIE[[i]][LIE[[i]]$Num==LIE[[i]]$Prec[end[k-1]+1],c(7:9, ncol(LIE[[i]]))], dataroot)}
             else{
               dataroot<-as.matrix(LIE[[i]][(end[k-1]+1):end[k],c(7:9, ncol(LIE[[i]]))])}}
           
-          lines3d(matrix(as.numeric(dataroot[,1:3]), ncol=3), col=dataroot[,4], smooth=FALSE, ...)}}
+          rgl::lines3d(dataroot[,1:3], col=dataroot[,4], smooth=FALSE, ...)}}
         
         else {
           
@@ -671,19 +674,23 @@ archigrow<-function(inputlie=NULL, inputtps=NULL, inputrsml=NULL,  res=NULL, uni
               end<-end[-1]
               end[length(end)+1]<-nrow(dataroot1)}
             else {end<-nrow(dataroot1)}
-            open3d()
-            plot3d(x=LIE[[i]]$X[1], y=LIE[[i]]$Y[1], z=LIE[[i]]$Z[1], type="n", xlim=xlim1, ylim=ylim1, zlim=zlim1, main=main1, ylab=ylab1, xlab=xlab1, zlab=zlab1,...)
+            
+            if (!requireNamespace("rgl", quietly = TRUE)) {
+              stop("3D plotting with archigrow() requires package `rgl`. Please install it and try again.")}
+            
+            rgl::open3d()
+            rgl::plot3d(x=LIE[[i]]$X[1], y=LIE[[i]]$Y[1], z=LIE[[i]]$Z[1], type="n", xlim=xlim1, ylim=ylim1, zlim=zlim1, main=main1, ylab=ylab1, xlab=xlab1, zlab=zlab1,...)
             for (k in 1:root){
               if (k==1) {
                 dataroot<-as.matrix(dataroot1[k:end[k],c(7:9, ncol(LIE[[i]]))])} 
               else {
                 if (dataroot1$Prec[end[k-1]+1]!=0){
                   dataroot<-as.matrix(dataroot1[(end[k-1]+1):end[k],c(7:9, ncol(LIE[[i]]))])
-                  dataroot<-as.matrix(rbind(dataroot1[dataroot1$Num==dataroot1$Prec[end[k-1]+1],c(7:9, ncol(LIE[[i]]))], dataroot))}
+                  dataroot<-rbind(dataroot1[dataroot1$Num==dataroot1$Prec[end[k-1]+1],c(7:9, ncol(LIE[[i]]))], dataroot)}
                 else{
                   dataroot<-as.matrix(dataroot1[(end[k-1]+1):end[k],c(7:9, ncol(LIE[[i]]))])}}
       
-              lines3d(matrix(as.numeric(dataroot[,1:3]), ncol=3), col=dataroot[,4], smooth=FALSE, ...)}}
+              rgl::lines3d(dataroot[,1:3], col=dataroot[,4], smooth=FALSE, ...)}}
             
             else {
               
@@ -818,19 +825,24 @@ archigrow<-function(inputlie=NULL, inputtps=NULL, inputrsml=NULL,  res=NULL, uni
               end<-end[-1]
               end[length(end)+1]<-nrow(dataroot1)}
             else {end<-nrow(dataroot1)}
-            open3d()
-            plot3d(x=LIE[[i]]$X[1], y=LIE[[i]]$Y[1], z=LIE[[i]]$Z[1], type="n", xlim=xlim1, ylim=ylim1, zlim=zlim1, main=main1, ylab=ylab1, xlab=xlab1, zlab=zlab1,...)
+            
+            if (!requireNamespace("rgl", quietly = TRUE)) {
+              stop("3D plotting with archigrow() requires package `rgl`. Please install it and try again.")}
+            
+            rgl::open3d()
+            rgl::plot3d(x=LIE[[i]]$X[1], y=LIE[[i]]$Y[1], z=LIE[[i]]$Z[1], type="n", xlim=xlim1, ylim=ylim1, zlim=zlim1, main=main1, ylab=ylab1, xlab=xlab1, zlab=zlab1,...)
+            
             for (k in 1:root){
               if (k==1) {
                 dataroot<-as.matrix(dataroot1[k:end[k],c(7:9, ncol(LIE[[i]]))])} 
               else {
                 if (dataroot1$Prec[end[k-1]+1]!=0){
                   dataroot<-as.matrix(dataroot1[(end[k-1]+1):end[k],c(7:9, ncol(LIE[[i]]))])
-                  dataroot<-as.matrix(rbind(dataroot1[dataroot1$Num==dataroot1$Prec[end[k-1]+1],c(7:9, ncol(LIE[[i]]))], dataroot))}
+                  dataroot<-rbind(dataroot1[dataroot1$Num==dataroot1$Prec[end[k-1]+1],c(7:9, ncol(LIE[[i]]))], dataroot)}
                 else{
                   dataroot<-as.matrix(dataroot1[(end[k-1]+1):end[k],c(7:9, ncol(LIE[[i]]))])}}
               
-              lines3d(matrix(as.numeric(dataroot[,1:3]), ncol=3), col=dataroot[,4], smooth=FALSE, ...)}}
+              rgl::lines3d(dataroot[,1:3], col=dataroot[,4], smooth=FALSE, ...)}}
             
             else {
               
